==> cscec5b-xell-impl-3.0.1-20230303.030542-59-sources.jar: com/ejianc/business/wzxt/util/Check.java <==
package com.ejianc.business.wzxt.util;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.List;

/**
 * <p>
 *
 * </p>
 *
 * @author sunyj
 * @since 2018-01-24
 */
public class Check extends BaseVO {

    private static final long serialVersionUID = 1L;

    private String pkCheck;
    private String pkOrg;
    private String pkProject;
    private String projectname;
    private String billcode;
    private String creator;
    private String checker;
    private String checktime;
    private String pkSupplier;
    private String suppliername;
    private String carnumber;
    private String isrequirement;
    private String isstandard;
    private String materialnumber;
    private String unit;
    private String checkprocess;
    private Integer nums;
    //原始单据图片url
    private String tpurl;
    //现场照片url
    private String sceneurl;
    private int checkStatus;
    private Integer rank;

    private String creatorDate;
    private String pkModified;//最后修改人
    private String modifiedDate;//最后修改时间

    private List<CheckB> checkBList;
    private String pkDelivery;
    private String deliveryCode;
    // 采购合同主键
    private String pkContractPurchase;
    // 采购合同名称
    private String contractPurchaseName;
    private String vdef1;
    private String sysmark;
    private String rejectReson;

    public String getPkCheck() {
        return pkCheck;
    }

    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getChecktime() {
        return checktime;
    }

    public void setChecktime(String checktime) {
        this.checktime = checktime;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    public String getCarnumber() {
        return carnumber;
    }

    public void setCarnumber(String carnumber) {
        this.carnumber = carnumber;
    }

    public String getIsrequirement() {
        return isrequirement;
    }

    public void setIsrequirement(String isrequirement) {
        this.isrequirement = isrequirement;
    }

    public String getIsstandard() {
        return isstandard;
    }

    public void setIsstandard(String isstandard) {
        this.isstandard = isstandard;
    }

    public String getMaterialnumber() {
        return materialnumber;
    }

    public void setMaterialnumber(String materialnumber) {
        this.materialnumber = materialnumber;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCheckprocess() {
        return checkprocess;
    }

    public void setCheckprocess(String checkprocess) {
        this.checkprocess = checkprocess;
    }

    public Integer getNums() {
        return nums;
    }

    public void setNums(Integer nums) {
        this.nums = nums;
    }

    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public int getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(int checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public String getPkModified() {
        return pkModified;
    }

    public void setPkModified(String pkModified) {
        this.pkModified = pkModified;
    }

    public String getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(String modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public List<CheckB> getCheckBList() {
        return checkBList;
    }

    public void setCheckBList(List<CheckB> checkBList) {
        this.checkBList = checkBList;
    }

    public String getPkDelivery() {
        return pkDelivery;
    }

    public void setPkDelivery(String pkDelivery) {
        this.pkDelivery = pkDelivery;
    }

    public String getDeliveryCode() {
        return deliveryCode;
    }

    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }

    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }

    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public String getRejectReson() {
        return rejectReson;
    }

    public void setRejectReson(String rejectReson) {
        this.rejectReson = rejectReson;
    }
}

==> cscec5b-xell-impl-3.0.1-20240315.030900-73-sources.jar: com/ejianc/business/wzxt/util/Check.java <==
package com.ejianc.business.wzxt.util;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.List;

/**
 * <p>
 *
 * </p>
 *
 * @author sunyj
 * @since 2018-01-24
 */
public class Check extends BaseVO {

    private static final long serialVersionUID = 1L;

    private String pkCheck;
    private String pkOrg;
    private String pkProject;
    private String projectname;
    private String billcode;
    private String creator;
    private String checker;
    private String checktime;
    private String pkSupplier;
    private String suppliername;
    private String carnumber;
    private String isrequirement;
    private String isstandard;
    private String materialnumber;
    private String unit;
    private String checkprocess;
    private Integer nums;
    //原始单据图片url
    private String tpurl;
    //现场照片url
    private String sceneurl;
    private int checkStatus;
    private Integer rank;

    private String creatorDate;
    private String pkModified;//最后修改人
    private String modifiedDate;//最后修改时间

    private List<CheckB> checkBList;
    private String pkDelivery;
    private String deliveryCode;
    // 采购合同主键
    private String pkContractPurchase;
    // 采购合同名称
    private String contractPurchaseName;
    private String vdef1;
    private String sysmark;
    private String rejectReson;

    private Long corpId; // 项目所属组织id
    private String corpName; // 项目所属组织名称
    private String corpSourceId; // 项目所属组织来源id

    public Long getCorpId() {
        return corpId;
    }

    public void setCorpId(Long corpId) {
        this.corpId = corpId;
    }

    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }

    public String getCorpSourceId() {
        return corpSourceId;
    }

    public void setCorpSourceId(String corpSourceId) {
        this.corpSourceId = corpSourceId;
    }

    public String getPkCheck() {
        return pkCheck;
    }

    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getChecker() {
        return checker;
    }

    public void setChecker(String checker) {
        this.checker = checker;
    }

    public String getChecktime() {
        return checktime;
    }

    public void setChecktime(String checktime) {
        this.checktime = checktime;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    public String getCarnumber() {
        return carnumber;
    }

    public void setCarnumber(String carnumber) {
        this.carnumber = carnumber;
    }

    public String getIsrequirement() {
        return isrequirement;
    }

    public void setIsrequirement(String isrequirement) {
        this.isrequirement = isrequirement;
    }

    public String getIsstandard() {
        return isstandard;
    }

    public void setIsstandard(String isstandard) {
        this.isstandard = isstandard;
    }

    public String getMaterialnumber() {
        return materialnumber;
    }

    public void setMaterialnumber(String materialnumber) {
        this.materialnumber = materialnumber;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCheckprocess() {
        return checkprocess;
    }

    public void setCheckprocess(String checkprocess) {
        this.checkprocess = checkprocess;
    }

    public Integer getNums() {
        return nums;
    }

    public void setNums(Integer nums) {
        this.nums = nums;
    }

    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public int getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(int checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public String getPkModified() {
        return pkModified;
    }

    public void setPkModified(String pkModified) {
        this.pkModified = pkModified;
    }

    public String getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(String modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public List<CheckB> getCheckBList() {
        return checkBList;
    }

    public void setCheckBList(List<CheckB> checkBList) {
        this.checkBList = checkBList;
    }

    public String getPkDelivery() {
        return pkDelivery;
    }

    public void setPkDelivery(String pkDelivery) {
        this.pkDelivery = pkDelivery;
    }

    public String getDeliveryCode() {
        return deliveryCode;
    }

    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }

    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }

    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public String getRejectReson() {
        return rejectReson;
    }

    public void setRejectReson(String rejectReson) {
        this.rejectReson = rejectReson;
    }
}
